@@ -154,12 +154,9 @@ step_slidify_augment_new <-
 #' @export
 prep.step_slidify_augment <- function(x, training, info = NULL, ...) {
 
-    col_names <- recipes::terms_select(x$terms, info = info)
-
-    if (any(info$type[info$variable %in% col_names] != "numeric"))
-        rlang::abort("The selected variables should be numeric")
-
+    col_names <- recipes::recipes_eval_select(x$terms, data = training, info = info)
 
+    check_type(training[, col_names])
 
     step_slidify_augment_new(
         terms    = x$terms,
