@@ -134,7 +134,7 @@ step_ts_clean_new <-
 #' @export
 prep.step_ts_clean <- function(x, training, info = NULL, ...) {
 
-    col_names <- terms_select(x$terms, info = info)
+    col_names <- recipes_eval_select(x$terms, data = training, info = info)
     recipes::check_type(training[, col_names])
 
     # Lambda Calculation
