@@ -165,7 +165,7 @@ step_ts_pad_new <-
 #' @export
 prep.step_ts_pad <- function(x, training, info = NULL, ...) {
 
-    col_names <- recipes::terms_select(x$terms, info = info)
+    col_names <- recipes::recipes_eval_select(x$terms, data = training, info = info)
 
     date_data <- info[info$variable %in% col_names, ]
 
@@ -173,7 +173,7 @@ prep.step_ts_pad <- function(x, training, info = NULL, ...) {
         rlang::abort("Only one column permitted")
     }
 
-    if (any(date_data$type != "date")) {
+    if (any(!date_data$type %in% c("date", "datetime"))) {
         rlang::abort(
             paste0("All variables for `step_ts_pad` should be either `Date` or",
                    " `POSIXct` classes."
