@@ -77,3 +77,19 @@ test_that("Skip/Insert Values", {
     )
     expect_identical(seq_0, seq_1)
 })
+
+test_that("End of Month", {
+
+    # Start Date
+    test <- timetk::tk_make_timeseries(start_date = '2011-09-30', by = 'quarter', length_out = 4)
+    expectation <- c("2011-09-30", "2011-12-31", "2012-03-31", "2012-06-30") %>% ymd()
+
+    expect_equal(test, expectation)
+
+    # End Date
+    test <- timetk::tk_make_timeseries(start_date = '2011-09-30', end_date = "2012-06-30", by = 'quarter')
+    expectation <- c("2011-09-30", "2011-12-31", "2012-03-31", "2012-06-30") %>% ymd()
+
+    expect_equal(test, expectation)
+
+})
